---
title: 가상계좌는 어떤 방식으로 연동할 수 있나요?
category: 자주 묻는 질문 (일반 문의) > 결제서비스 > 결제서비스
seo:
  title: 가상계좌 서비스 특징 상세 안내
  description: >-
    가상계좌를 이용한다면 필수적으로 알아야 할 가상계좌의 특성을 설명드립니다. 가상계좌 특성부터, 필수 설정, 연동가능 방식까지, 포트원이
    준비한 가이드를 확인해보세요.
  keywords:
    - 일반
tags:
  - 공통
  - 일반결제
  - 가상계좌
pgCompanies:
  - 공통
searchTags:
  - API방식
  - 결제창방식
  - 회전식
  - 고정식
  - 무통장입금
  - 입금통보
  - 입금통지
  - 웹훅
  - 가상계좌연동
  - 가상계좌환불
  - 가상계좌
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="포트원에서 제공해드리는 가상계좌의 특성과 연동시 유의사항까지 안내드립니다." />

### **포트원에서 지원하는 가상계좌의 특성**

가상계좌는 가상의 계좌를 먼저 발급받고 고객이 원하는 시간에 입금을 하는 결제수단입니다.

입금시 사업자의 서버로 입금통지를 줌으로써 사업자에서는 입금완료에 대한 주문처리를 진행합니다. 입금된 결제금은 결제대행사(PG사)에서 가지고 있다가 추후 사업자의 계좌로 정산이 이루어지며, 고객이 사업자의 계좌로 직접 입금하는 무통장입금 서비스과는 다소 차이가 있습니다.

포트원에서 제공드리는 가상계좌는 회전식 과 고정식이 있습니다.

- **회전식 가상계좌** : 포트원은 매 결제 시도시마다 새로운 계좌정보가 발급되는 **회전식** 방식을 지원합니다.
- **고정식 가상계좌** : 고객별로 고정된 가상계좌 정보를 부여하는 방식인 **고정식**은 현재  KCP, 나이스페이먼츠, 스마트로, kg이니시스, 토스페이먼츠 에서 지원합니다.

### **가상계좌 연동시 필수 설정사항**

계좌를 채번(발급)했을 때 부여되는 기본 결제상태는 **status : ready(미결제)** 이며 구매자가 입금을 했을 때 \*\*status: paid (결제완료)\*\*로 변경됩니다.

구매자 입금에 대한 통지는 결제대행사 (PG사) > 포트원 > 사업자 순으로 전달되며 이를 위해 아래 2가지 사항을 반드시 설정해주셔야 합니다. 미설정시 구매자가 입금을 했음에도 결제상태가 '미결제'로 남아있게 되오니 유의하여 주시기 바랍니다.

1. PG사 > 포트원으로 입금통지 : 가상계좌 입금통보 URL 설정\
   (테스트용 상점아이디에는 자동으로 설정되어있습니다.)
2. 포트원 > 고객사 서버로 입금통지: 결제알림(Webhook) 관리 설정\
   (웹훅 설정방법 : 포트원 관리자콘솔 > 결제연동 > 결제알림(Webhook) 관리 > Endpoint URL 입력)





### **가상계좌 연동 가능 방식**

가상계좌 발급은 결제대행사의 결제창을 띄워 발급받는 결제창방식 과 API 호출로 발급받는 API 방식을 모두 지원합니다. 각 방식별로 지원가능한 결제대행사는 다음과 같습니다.

- **결제창 방식** : NHN KCP, KG이니시스, KG모빌리언스, 나이스페이먼츠, 다날, 헥토파이낸셜(구 세틀뱅크), 토스페이먼츠, 다우데이타 , 스마트로, KSNET, 이지페이(KICC) , 웰컴페이먼츠
- **API 방식** : 헥토파이낸셜(구 세틀뱅크) , 나이스페이먼츠, KG이니시스, 토스페이먼츠, KSNET, 스마트로(신모듈), 나이스페이먼츠(신모듈), 웰컴페이먼츠 , KCP(v2)

<Callout title="REST API - V2 가상계좌 발급 API 연동 가이드 보러가기 ↗" />
